==> haskell-http-common-0.8.2.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-common
version: 0.8.2.0
id: http-common-0.8.2.0-ArwORgdjzaUBimhan937zs
key: http-common-0.8.2.0-ArwORgdjzaUBimhan937zs
license: BSD-3-Clause
copyright: © 2012-2015 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: http://research.operationaldynamics.com/projects/http-streams/
synopsis: Common types for HTTP clients and servers
description:
    /Overview/
    .
    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.
category: Web
abi: 65c2c882cf3e87d36a5e5eee1356daf3
exposed: True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-common-0.8.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-common-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-common-0.8.2.0
hs-libraries: HShttp-common-0.8.2.0-ArwORgdjzaUBimhan937zs
depends:
    base-4.11.1.0 directory-1.3.1.5
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra mtl-2.2.2
    transformers-0.5.5.0 network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr
    text-1.2.3.0 unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr=64a54c687aa7806d1b651ff4086a22e3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html: /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-common-0.8.2.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-common
version: 0.8.2.0
id: http-common-0.8.2.0-20CxTmKeE8xFDGioRM8ohE
key: http-common-0.8.2.0-20CxTmKeE8xFDGioRM8ohE
license: BSD-3-Clause
copyright: © 2012-2015 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: http://research.operationaldynamics.com/projects/http-streams/
synopsis: Common types for HTTP clients and servers
description:
    /Overview/
    .
    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.
category: Web
abi: 48b9d1228a5273acf3adbbeda419fb5b
exposed: True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-common-0.8.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-common-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-common-0.8.2.0
hs-libraries: HShttp-common-0.8.2.0-20CxTmKeE8xFDGioRM8ohE
depends:
    base-4.11.1.0 directory-1.3.1.5
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra mtl-2.2.2
    transformers-0.5.5.0 network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK
    text-1.2.3.0 unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK=94d8930bfafd62e59b581d22ac71f05d
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html: /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
